/*************************************************************

  ArduinoGPIO.ino

  Accepts UDP traffic and turns a pin on or off.
  DHCP to obtain IP address.

  Written by Daniel Raines Communications on 06/04/2019
  http://DanielRaines.com | http://BreeCS.com

*************************************************************/

#include <Ethernet.h>
#include <EthernetUDP.h>
#include <utility/w5100.h>
byte mac[] = { 0x20, 0x19, 0xCA, 0xB0, 0x00, 0x11 };
const unsigned int udpListenPort = 9501;
EthernetUDP UDP;

void setup() {
  initPins();
  Ethernet.begin(mac);
  UDP.begin(udpListenPort);
  W5100.setRetransmissionCount(3);  
}

void initPins() {
  for (int i = 0; i < 14; i++) {
    pinMode(i, OUTPUT);
    digitalWrite(i, LOW);
  }
}

String parseData(String data, char separator, int index) {
  int found = 0;
  int strIndex[] = {0, -1};
  int maxIndex = data.length() - 1;
  for (int i = 0; i <= maxIndex && found <= index; i++) {
    if (data.charAt(i) == separator || i == maxIndex) {
      found++;
      strIndex[0] = strIndex[1] + 1;
      strIndex[1] = (i == maxIndex) ? i + 1 : i;
    }
  }
  return found > index ? data.substring(strIndex[0], strIndex[1]) : "";
}

void loop() {
  int packetSize = UDP.parsePacket();
  if (packetSize) {
    char packetBuffer[packetSize];
    UDP.read(packetBuffer, packetSize);
    int pinNo = 0;
    int state = 0;

    if (parseData(packetBuffer, ',', 0) == "StreamDeck") {
      pinNo = parseData(packetBuffer, ',', 1).toInt();
      state = parseData(packetBuffer, ',', 2).toInt();

      if (state == 2) {
        digitalWrite(pinNo, 0);
        delay(100);
        digitalWrite(pinNo, 1);
        delay(1000);
        digitalWrite(pinNo, 0);
      } else {
        digitalWrite(pinNo, state);
      }
    }
  }
  
  delay(10);
}

