﻿//--------------------------------------------------------------
// Stream Deck Home Automate
// Written by Daniel Raines Communications
// 06/04/2019
// http://DanielRaines.com | https://BreeCS.com
//
// From Stream Deck buttons (System: Open)...
// StreamDeckControlled.exe PIN STATE(0 OFF, 1 ON, 2 MOMENTARY)
//
// For example, to turn PIN 2 ON...
// StreamDeckControlled.exe 2 1
//--------------------------------------------------------------

using System;
using System.Text;
using System.Windows.Forms;
using System.Net;
using System.Net.Sockets;
using System.Net.NetworkInformation;

namespace StreamDeckControlled
{
    public partial class frmMain : Form
    {
        protected override bool ShowWithoutActivation
        {
            get { return true; }
        }

        private bool noGUI = false;

        public frmMain(int pin, int state)
        {
            InitializeComponent();
            if (pin > 0 && pin < 14 && state > -1 && state < 3)
            {
                noGUI = true;
                controlEndpoint(pin, state);
            }
        }

        private void frmMain_Load(object sender, EventArgs e)
        {
            if (noGUI)
            { 
                this.Top = -10000;
                Application.Exit();
            }
        }

        private void sendData_Click(object sender, EventArgs e)
        {
            controlEndpoint((Int32)numPin.Value, (Int32)numState.Value);
        }

        #region Send UDP Data to Endpoints
        private void controlEndpoint(int pin, int state)
        {
            foreach (NetworkInterface item in NetworkInterface.GetAllNetworkInterfaces())
            {
                if (item.OperationalStatus == OperationalStatus.Up)
                {
                    foreach (UnicastIPAddressInformation ip in item.GetIPProperties().UnicastAddresses)
                    {
                        if (ip.Address.AddressFamily == AddressFamily.InterNetwork)
                        {
                            string[] ipOctets = ip.Address.ToString().Split('.');

                            if (ipOctets[0] != "169" && ipOctets[0] != "127")
                            {
                                using (Socket BroadcastSocket = new Socket(AddressFamily.InterNetwork, SocketType.Dgram, ProtocolType.Udp))
                                {
                                    IPAddress BroadcastAddress = IPAddress.Parse(ipOctets[0] + "." + ipOctets[1] + "." + ipOctets[2] + ".255");
                                    IPEndPoint BroadcastEndPoint = new IPEndPoint(BroadcastAddress, 9501);
                                    byte[] BroadcastBuffer = Encoding.ASCII.GetBytes("StreamDeck," + pin + "," + state + ",END");

                                    try
                                    {
                                        BroadcastSocket.SendTo(BroadcastBuffer, BroadcastEndPoint);
                                        BroadcastSocket.Close();
                                    }
                                    catch { }
                                }
                            }
                        }
                    }
                }
            }
        }
        #endregion

    }
}
